<?php
/*
Plugin Name: Tag Desindexer
Description: Añade opciones para desindexar etiquetas de productos y etiquetas de entradas en WordPress mediante noindex y nofollow.
Version: 1.0
Author: Nacho García - <a href="https://ayudainternet.com">Ayudainternet.com</a>
*/

// Evitar acceso directo
if (!defined('ABSPATH')) {
    exit;
}

// Función para añadir opciones a la creación de etiquetas
function tag_desindexer_add_meta_fields($taxonomy) {
    // Comprobamos si la gestión de etiquetas está habilitada para el tipo de etiqueta correspondiente
    if (($taxonomy === 'product_tag' && get_option('tag_desindexer_enable_product_tags', '1') === '1') || 
        ($taxonomy === 'post_tag' && get_option('tag_desindexer_enable_post_tags', '1') === '1')) {
        ?>
        <div class="form-field">
            <label for="noindex"><?php _e('Desindexar mediante noindex', 'tag-desindexer'); ?></label>
            <input type="checkbox" name="noindex" id="noindex" value="1" />
            <p class="description"><?php _e('Añadir meta noindex a esta etiqueta', 'tag-desindexer'); ?></p>
        </div>
        <div class="form-field">
            <label for="nofollow"><?php _e('Desindexar mediante nofollow', 'tag-desindexer'); ?></label>
            <input type="checkbox" name="nofollow" id="nofollow" value="1" />
            <p class="description"><?php _e('Añadir meta nofollow a esta etiqueta', 'tag-desindexer'); ?></p>
        </div>
        <?php
    }
}

// Función para añadir opciones a la edición de etiquetas
function tag_desindexer_edit_meta_fields($term, $taxonomy) {
    // Comprobamos si la gestión de etiquetas está habilitada para el tipo de etiqueta correspondiente
    if (($taxonomy === 'product_tag' && get_option('tag_desindexer_enable_product_tags', '1') === '1') || 
        ($taxonomy === 'post_tag' && get_option('tag_desindexer_enable_post_tags', '1') === '1')) {
        $noindex = get_term_meta($term->term_id, '_noindex', true);
        $nofollow = get_term_meta($term->term_id, '_nofollow', true);

        ?>
        <tr class="form-field">
            <th scope="row" valign="top"><label for="noindex"><?php _e('Desindexar mediante noindex', 'tag-desindexer'); ?></label></th>
            <td>
                <input type="checkbox" name="noindex" id="noindex" <?php checked($noindex, '1'); ?> value="1" />
                <p class="description"><?php _e('Añadir meta noindex a esta etiqueta', 'tag-desindexer'); ?></p>
            </td>
        </tr>
        <tr class="form-field">
            <th scope="row" valign="top"><label for="nofollow"><?php _e('Desindexar mediante nofollow', 'tag-desindexer'); ?></label></th>
            <td>
                <input type="checkbox" name="nofollow" id="nofollow" <?php checked($nofollow, '1'); ?> value="1" />
                <p class="description"><?php _e('Añadir meta nofollow a esta etiqueta', 'tag-desindexer'); ?></p>
            </td>
        </tr>
        <?php
    }
}

// Función para guardar los valores de las opciones
function tag_desindexer_save_tag_meta_fields($term_id) {
    $noindex = isset($_POST['noindex']) ? '1' : '';
    $nofollow = isset($_POST['nofollow']) ? '1' : '';

    update_term_meta($term_id, '_noindex', $noindex);
    update_term_meta($term_id, '_nofollow', $nofollow);
}

// Función para añadir las meta tags al head
function tag_desindexer_add_meta_tags() {
    if (is_tax('product_tag') && get_option('tag_desindexer_enable_product_tags', '1') === '1') {
        $term_id = get_queried_object_id();
        $noindex = get_term_meta($term_id, '_noindex', true);
        $nofollow = get_term_meta($term_id, '_nofollow', true);

        if ($noindex && $nofollow) {
            echo '<meta name="robots" content="noindex, nofollow">' . "\n";
        } elseif ($noindex) {
            echo '<meta name="robots" content="noindex">' . "\n";
        } elseif ($nofollow) {
            echo '<meta name="robots" content="nofollow">' . "\n";
        }
    } elseif (is_tag() && get_option('tag_desindexer_enable_post_tags', '1') === '1') {
        $term_id = get_queried_object_id();
        $noindex = get_term_meta($term_id, '_noindex', true);
        $nofollow = get_term_meta($term_id, '_nofollow', true);

        if ($noindex && $nofollow) {
            echo '<meta name="robots" content="noindex, nofollow">' . "\n";
        } elseif ($noindex) {
            echo '<meta name="robots" content="noindex">' . "\n";
        } elseif ($nofollow) {
            echo '<meta name="robots" content="nofollow">' . "\n";
        }
    }
}

// Función para añadir una columna personalizada en la lista de etiquetas de productos y entradas
function tag_desindexer_add_tag_columns($columns) {
    $columns['desindex_status'] = __('Desindexación', 'tag-desindexer');
    return $columns;
}

// Función para mostrar la información de desindexación en la columna personalizada
function tag_desindexer_manage_tag_columns($out, $column, $term_id) {
    if ($column === 'desindex_status') {
        $noindex = get_term_meta($term_id, '_noindex', true);
        $nofollow = get_term_meta($term_id, '_nofollow', true);

        if ($noindex && $nofollow) {
            $out = __('Noindex, Nofollow', 'tag-desindexer');
        } elseif ($noindex) {
            $out = __('Noindex', 'tag-desindexer');
        } elseif ($nofollow) {
            $out = __('Nofollow', 'tag-desindexer');
        } else {
            $out = __('Indexado', 'tag-desindexer');
        }
    }
    return $out;
}

// Función para añadir la página de configuración en el menú de herramientas
function tag_desindexer_admin_menu() {
    add_submenu_page(
        'tools.php',
        __('Tag Desindexer', 'tag-desindexer'),
        __('Tag Desindexer', 'tag-desindexer'),
        'manage_options',
        'tag-desindexer',
        'tag_desindexer_settings_page'
    );
}

// Función para mostrar la página de configuración
function tag_desindexer_settings_page() {
    if (!current_user_can('manage_options')) {
        return;
    }

    // Guardar opciones
    if (isset($_POST['tag_desindexer_save'])) {
        check_admin_referer('tag_desindexer_save_settings', 'tag_desindexer_nonce');
        update_option('tag_desindexer_enable_product_tags', isset($_POST['enable_product_tags']) ? '1' : '0');
        update_option('tag_desindexer_enable_post_tags', isset($_POST['enable_post_tags']) ? '1' : '0');
        echo '<div class="updated"><p>' . __('Configuración guardada.', 'tag-desindexer') . '</p></div>';
    }

    // Obtener opciones
    $enable_product_tags = get_option('tag_desindexer_enable_product_tags', '1');
    $enable_post_tags = get_option('tag_desindexer_enable_post_tags', '1');

    ?>
    <div class="wrap">
        <h1><?php _e('Configuración de Tag Desindexer', 'tag-desindexer'); ?></h1>
        <form method="post" action="">
            <?php wp_nonce_field('tag_desindexer_save_settings', 'tag_desindexer_nonce'); ?>
            <table class="form-table">
                <tr valign="top">
                    <th scope="row"><?php _e('Habilitar gestión para etiquetas de productos', 'tag-desindexer'); ?></th>
                    <td><input type="checkbox" name="enable_product_tags" value="1" <?php checked($enable_product_tags, '1'); ?> /></td>
                </tr>
                <tr valign="top">
                    <th scope="row"><?php _e('Habilitar gestión para etiquetas de entradas', 'tag-desindexer'); ?></th>
                    <td><input type="checkbox" name="enable_post_tags" value="1" <?php checked($enable_post_tags, '1'); ?> /></td>
                </tr>
            </table>
            <p class="submit"><input type="submit" name="tag_desindexer_save" class="button-primary" value="<?php _e('Guardar cambios', 'tag-desindexer'); ?>" /></p>
        </form>
    </div>
    <?php
}

// Registrar acciones condicionalmente según configuración
function tag_desindexer_register_actions() {
    add_action('created_product_tag', 'tag_desindexer_save_tag_meta_fields', 10, 2);
    add_action('created_post_tag', 'tag_desindexer_save_tag_meta_fields', 10, 2);
    add_action('edited_product_tag', 'tag_desindexer_save_tag_meta_fields', 10, 2);
    add_action('edited_post_tag', 'tag_desindexer_save_tag_meta_fields', 10, 2);

    if (get_option('tag_desindexer_enable_product_tags', '1') === '1') {
        add_action('product_tag_add_form_fields', 'tag_desindexer_add_meta_fields', 10, 1);
        add_action('product_tag_edit_form_fields', 'tag_desindexer_edit_meta_fields', 10, 2);
        add_filter('manage_edit-product_tag_columns', 'tag_desindexer_add_tag_columns');
        add_filter('manage_product_tag_custom_column', 'tag_desindexer_manage_tag_columns', 10, 3);
    }

    if (get_option('tag_desindexer_enable_post_tags', '1') === '1') {
        add_action('post_tag_add_form_fields', 'tag_desindexer_add_meta_fields', 10, 1);
        add_action('post_tag_edit_form_fields', 'tag_desindexer_edit_meta_fields', 10, 2);
        add_filter('manage_edit-post_tag_columns', 'tag_desindexer_add_tag_columns');
        add_filter('manage_post_tag_custom_column', 'tag_desindexer_manage_tag_columns', 10, 3);
    }
}

// Inicializar configuración
add_action('admin_init', 'tag_desindexer_register_actions');

// Añadir menú de configuración
add_action('admin_menu', 'tag_desindexer_admin_menu');

// Añadir meta tags al head
add_action('wp_head', 'tag_desindexer_add_meta_tags');


// Añadir enlace "Gestionar" en la lista de plugins
function tag_desindexer_plugin_action_links($links) {
    $settings_link = '<a href="tools.php?page=tag-desindexer">' . __('Ajustes', 'tag-desindexer') . '</a>';
    array_unshift($links, $settings_link);
    return $links;
}

add_filter('plugin_action_links_' . plugin_basename(__FILE__), 'tag_desindexer_plugin_action_links');
?>